@@ -682,6 +682,7 @@ Visualizations examples:
     AudioContainer.set_focus
     AudioContainer.get_focused
     AudioContainer.freeze
+    AudioContainer.frames
     AudioContainer.normalize
     AudioContainer.resample
     AudioContainer.mixdown
@@ -756,6 +757,7 @@ MetaDataItem
     MetaDataItem.offset
     MetaDataItem.identifier
     MetaDataItem.source_label
+    MetaDataItem.set_label
     MetaDataItem.tags
     MetaDataItem.active_within_segment
 
@@ -779,23 +781,30 @@ MetaDataContainer
     MetaDataContainer.event_count
     MetaDataContainer.scene_label_count
     MetaDataContainer.event_label_count
+    MetaDataContainer.identifier_count
     MetaDataContainer.tag_count
     MetaDataContainer.unique_files
     MetaDataContainer.unique_event_labels
     MetaDataContainer.unique_scene_labels
     MetaDataContainer.unique_tags
     MetaDataContainer.unique_identifiers
+    MetaDataContainer.unique_source_labels
     MetaDataContainer.max_offset
-    MetaDataContainer.get_string
+    MetaDataContainer.to_string
     MetaDataContainer.filter
     MetaDataContainer.filter_time_segment
     MetaDataContainer.process_events
+    MetaDataContainer.map_events
+    MetaDataContainer.event_inactivity
     MetaDataContainer.add_time
     MetaDataContainer.stats
     MetaDataContainer.scene_stat_counts
     MetaDataContainer.event_stat_counts
     MetaDataContainer.tag_stat_counts
     MetaDataContainer.to_event_roll
+    MetaDataContainer.intersection
+    MetaDataContainer.intersection_report
+    MetaDataContainer.difference
 
 Parameter containers
 ::::::::::::::::::::
@@ -821,9 +830,15 @@ AppParameterContainer
     AppParameterContainer
     AppParameterContainer.reset
     AppParameterContainer.process
+    AppParameterContainer.process_set
     AppParameterContainer.override
     AppParameterContainer.get_path_translated
     AppParameterContainer.set_path_translated
+    AppParameterContainer.update_parameter_set
+    AppParameterContainer.set_ids
+    AppParameterContainer.set_id_exists
+    AppParameterContainer.active_set
+    AppParameterContainer.get_set
 
 
 DCASEAppParameterContainer
@@ -849,7 +864,6 @@ ParameterListContainer
 Probability containers
 ::::::::::::::::::::::
 
-
 ProbabilityItem
 ---------------
 
@@ -881,9 +895,11 @@ ProbabilityContainer
     ProbabilityContainer.load
     ProbabilityContainer.save
     ProbabilityContainer.append
-    ProbabilityContainer.file_list
+    ProbabilityContainer.unique_files
     ProbabilityContainer.unique_labels
+    ProbabilityContainer.unique_indices
     ProbabilityContainer.filter
+    ProbabilityContainer.as_matrix
 
 Mixins
 ::::::
